@@ -159,7 +159,7 @@ void KineticList::_unselect(User* sel)
 
     lastSelected = sel;
 
-    Account::instance()->setSelected(sel->getUsername());
+    AccountManager::instance()->setSelected(sel->getUsername());
 
     emit selected(true);
 }
