@@ -39,27 +39,16 @@ class LineEditBox : public QLineEdit
     Q_OBJECT
 
 public:
-    LineEditBox()
-            : QLineEdit() {
-    }
-
-    ~LineEditBox() {
+    LineEditBox() : QLineEdit() {
     }
 
 protected:
-    void focusInEvent(QFocusEvent *event) {
-        QLineEdit::focusInEvent(event);
+    void mousePressEvent(QMouseEvent *) {
         emit gainedFocus();
     }
 
-    void focusOutEvent(QFocusEvent *event) {
-        QLineEdit::focusOutEvent(event);
-        emit lostFocus();
-    }
-
 signals:
     void gainedFocus(void);
-    void lostFocus(void);
 };
 
 /*!
@@ -76,7 +65,6 @@ public:
     enum TypeLineEdit{ Short, Long };
 
     LineEdit(LineEdit::TypeLineEdit type , QGraphicsWidget *parent = 0);
-    ~LineEdit();
     void setEchoMode(QLineEdit::EchoMode echo);
     void setMessage(QString message);
     QString getText(void);
@@ -84,6 +72,8 @@ public:
     void enable(bool option);
     void setMaxLength(int length);
     void clearText(void);
+    void setAlignment(Qt::Alignment flag);
+    void setValidator(const QValidator*);
 
     QRectF boundingRect() const {
         return _image->boundingRect();
@@ -108,9 +98,9 @@ private slots:
 
 protected:
     virtual void keyReleaseEvent(QKeyEvent *event);
+    virtual void keyPressEvent(QKeyEvent *event);
     virtual void mousePressEvent(QGraphicsSceneMouseEvent *event);
     virtual void mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event);
-    virtual void keyPressEvent(QKeyEvent *event);
 
 private:
     QGraphicsPixmapItem *_image;
