@@ -29,12 +29,14 @@
 #include "twitterapi/entry.h"
 #include "twitterapplicationitem.h"
 
+#include "account/accountManager.h"
+
 class User : public TwitterApplicationItem
 {
     Q_OBJECT
 
 public:
-    User(QString username, QImage avatar, QGraphicsWidget *parent = 0);
+    User(Account* account = 0, QGraphicsWidget *parent = 0);
     void unselect(void);
     void select(void);
     QString getUsername(void);
