@@ -167,7 +167,7 @@ void TimelineCtrl::_handleGPSLocation()
 
 void TimelineCtrl::_populateHome(void)
 {
-    EntryList entries = Backend::getInstance()->homeTweets();
+    EntryList entries = Backend::getInstance()->getHomeTweets();
 
     foreach( const Entry &entry, entries ) {
         Tweet *tweet = new Tweet(entry,NULL);
@@ -180,7 +180,7 @@ void TimelineCtrl::_populateHome(void)
 
 void TimelineCtrl::_populateMentions(void)
 {
-    EntryList entries = Backend::getInstance()->mentionsTweets();
+    EntryList entries = Backend::getInstance()->getMentionsTweets();
 
     foreach( const Entry &entry, entries ) {
         Tweet *tweet = new Tweet(entry,NULL);
@@ -193,12 +193,10 @@ void TimelineCtrl::_populateMentions(void)
 
 void TimelineCtrl::_updatePosted(void)
 {
-    EntryList entries = Backend::getInstance()->homeTweets();
+    Entry entry = Backend::getInstance()->getUpdateTweet();
 
-    foreach( const Entry &entry, entries ) {
-        Tweet *tweet = new Tweet(entry,NULL);
-        _timelineView->_homeTimeline->addToList(tweet,0);
-    }
+    Tweet *tweet = new Tweet(entry,NULL);
+    _timelineView->_homeTimeline->addToList(tweet,0);
 
     _timelineView->_statusId = 0;
     _timelineView->clearText();
