@@ -366,17 +366,16 @@ int XmlParser::calculateTimeShift()
 
 QString XmlParser::textToHtml( QString newText )
 {
-    // URL_IDENTICA = http://identi.ca/api
     newText.replace( "<", "&lt;" );
     newText.replace( ">", "&gt;" );
 
     // recognize #hashtags
-    QRegExp tag( "#([\\w\\d-]+)( ?)", Qt::CaseInsensitive );
-    newText.replace( tag, "<font color=#0f95da>#\\1</font>\\2");
+    QRegExp tag( "(^|\\s)#([A-Za-z0-9-_]+)+", Qt::CaseInsensitive );
+    newText.replace( tag, " <font color=#0f95da>#\\2</font> ");
 
     // recognize web/ftp links
-    QRegExp ahref( "((https?|ftp)://[^ ]+)( ?)", Qt::CaseInsensitive );
-    newText.replace( ahref, "<font color=#0f95da>\\1</font>\\3" );
+    QRegExp ahref( "((?:https?|ftp)://\\S+)", Qt::CaseInsensitive );
+    newText.replace( ahref, "<font color=#0f95da>\\1</font>" );
 
     // recognize @mentions (letters, numbers are allowed in nicks)
     // for Twitter, also allow _ in nicks and @user/list;
